---
title: <span class="badge builder"></span> BaseBucketAggregation
---
# <span class="badge builder"></span> BaseBucketAggregation

## Constructor

```python
BaseBucketAggregation()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> elasticsearch.BaseBucketAggregation
```

### <span class="badge object-method"></span> id_val

```python
def id_val(id_val: str) -> typing.Self
```

### <span class="badge object-method"></span> settings

```python
def settings(settings: object) -> typing.Self
```

### <span class="badge object-method"></span> type_val

```python
def type_val(type_val: elasticsearch.BucketAggregationType) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [BaseBucketAggregation](./object-BaseBucketAggregation.md)
